Other Vignettes
---------------

Example Datasets
^^^^^^^^^^^^^^^^
- `Dentate Gyrus <DentateGyrus>`_
- `Pancreas <Pancreas>`_

Nature Biotech Figures
^^^^^^^^^^^^^^^^^^^^^^

- NBT Cover           | `cover <https://www.nature.com/nbt/volumes/38/issues/12>`__ | `notebook <NatureBiotechCover>`__
- Fig.1 Concept       | `figure <https://www.nature.com/articles/s41587-020-0591-3/figures/1>`__ | `notebook <Fig1_concept>`__
- Fig.2 Dentate Gyrus | `figure <https://www.nature.com/articles/s41587-020-0591-3/figures/2>`__ | `notebook <Fig2_dentategyrus>`__
- Fig.3 Pancreas      | `figure <https://www.nature.com/articles/s41587-020-0591-3/figures/3>`__ | `notebook <Fig3_pancreas>`__
- Suppl. Figures      | `figure <https://static-content.springer.com/esm/art%3A10.1038%2Fs41587-020-0591-3/MediaObjects/41587_2020_591_MOESM1_ESM.pdf>`__ | `notebook <FigSuppl>`__ | `runtime <FigS9_runtime>`__

All notebooks are deposited at `GitHub <https://github.com/theislab/scvelo_notebooks>`_.
Found a bug? Feel free to submit an `issue <https://github.com/theislab/scvelo/issues/new/choose>`_.